SiBus Lib - Library for creating SiBus clients and servers
========================================================

Vous pouvez l'installer avec pip:

    pip install sibus_lib

Exemple d'usage:

    >>> from sibus_lib import proclamer
    >>> proclamer()

Ce code est sous licence WTFPL.
